<div class="step-container"
    style="display: flex; justify-content: space-between; align-self: stretch; margin-left: 1.5rem;">
    <div style="display: flex; align-items:center; gap: 0.25rem; margin: 0; padding: 0; ">
        {% import './components/icon.html' as icon %}
        {% if status == "passed" %}
        {{icon.pass()}}
        {% elif status == "failed" %}
        {{icon.fail()}}
        {% else %}
        {{icon.skip()}}
        {% endif %}
        <p style="display: inline; margin: 0;">
            <span class="keyword" style="font-weight: 500;">{{keyword}}</span>: {{name}}
        </p>
    </div>
    <p style="display: inline; margin: 0;">
        {% if (duration/1_000_000) > 1 %}
        {{(duration/1_000_000_000)|round(3)}}s
        {% else %}
        {{(duration/1_000_000)|round(3)}}ms
        {%endif%}
    </p>
</div>