<a href="#feature-statistics" id="feature-statistics-button"
    style="position: fixed;z-index: 10; bottom: 1rem; right: 1rem; background-color: white;color: black; padding: 0.5rem 1rem; border-radius: 50px;box-shadow: 0px 2px 5px 0px rgba(0, 0, 0, 0.10);">
    Return to top
</a>