{% macro gray(duration, premble='') -%}
<p style="color: #535353;
        font-family: Roboto;
        font-size: 1rem;
        font-style: normal;
        font-weight: 400;
        line-height: normal;">
    {% if duration > 1 %}
    {{preamble}} {{duration|round(3)}}s
    {% else %}
    {{preamble}} {{(duration*1000)|round(3)}}ms
    {%endif%}
</p>
{%- endmacro %}

{%- macro black(duration, premble='') -%}
<p style="color: #1a1a1a;
        font-family: Roboto;
        font-size: 1rem;
        font-style: normal;
        font-weight: 400;
        line-height: normal;">
    {% if duration > 1 %}
    {{preamble}} {{duration|round(3)}}s
    {% else %}
    {{preamble}} {{(duration*1000)|round(3)}}ms
    {%endif%}
</p>
{%- endmacro %}